#define ICON_BOCHS  1000

#define ASK_DLG     2000
#define IDASKTX1    2010
#define IDASKDEV    2020
#define IDASKTX2    2030
#define IDASKMSG    2040
#define IDASKLIST   2050
#define STRING_DLG  2100
#define IDSTRING    2110
#define FLOPPY_DLG  2200
#define IDDEVTX     2205
#define IDDEVTYPE   2210
#define IDPATHTX    2215
#define IDPATH      2220
#define IDBROWSE    2230
#define IDMEDIATX   2235
#define IDMEDIATYPE 2240
#define IDSTATUS    2250
#define IDCREATE    2260
#define IDCHANGETX  2265
#define CDROM1_DLG  2300
#define RT_CDROM_DLG 2400
#define IDGROUP1    2411
#define IDGROUP2    2412
#define IDGROUP3    2413
#define IDGROUP4    2414
#define IDLABEL1    2421
#define IDLABEL2    2422
#define IDLABEL3    2423
#define IDLABEL4    2424
#define IDCDROM1    2431
#define IDCDROM2    2432
#define IDCDROM3    2433
#define IDCDROM4    2434
#define IDBROWSE1   2441
#define IDBROWSE2   2442
#define IDBROWSE3   2443
#define IDBROWSE4   2444
#define IDSTATUS1   2451
#define IDSTATUS2   2452
#define IDSTATUS3   2453
#define IDSTATUS4   2454
#define RT_LOGOPT_DLG 2500
#define IDDEVLIST   2510
#define IDLOGLBL1   2521
#define IDLOGLBL2   2522
#define IDLOGLBL3   2523
#define IDLOGLBL4   2524
#define IDLOGLBL5   2525
#define IDLOGEVT1   2531
#define IDLOGEVT2   2532
#define IDLOGEVT3   2533
#define IDLOGEVT4   2534
#define IDLOGEVT5   2535
#define IDADVLOGOPT 2540
#define RT_MISC_DLG 2600
#define IDMISCLBL1  2611
#define IDMISCLBL2  2612
#define IDMISCLBL3  2613
#define IDMISCLBL4  2614
#define IDMISCLBL5  2615
#define IDVGAUPDATE 2620
#define IDMOUSE     2630
#define IDKBDPASTE  2640
#define IDUSERBTN   2650
#define IDSB16TIMER 2660
#define IDSBLOGLEV  2670
#define RT_USBDEV_DLG 2700
#define IDUSBLBL1  2711
#define IDUSBLBL2  2712
#define IDUSBWARN  2715
#define IDUSBDEV1  2620
#define IDUSBDEV2  2640
#define DEBUGGER_DLG 3000
#define DEBUG_MSG  3010
#define DEBUG_CMD  3020
#define IDEXEC     3030
#define IDSTOP     3040
#define IDSHOWCPU  3050
#define IDCPULBL1  3061
#define IDCPULBL2  3062
#define IDCPULBL3  3063
#define IDCPULBL4  3064
#define IDCPULBL5  3065
#define IDCPULBL6  3066
#define IDCPULBL7  3067
#define IDCPULBL8  3068
#define IDCPULBL9  3069
#define IDCPULBL10 3070
#define IDCPULBL11 3071
#define IDCPULBL12 3072
#define IDCPULBL13 3073
#define IDCPULBL14 3074
#define IDCPULBL15 3075
#define IDCPULBL16 3076
#define IDCPUVAL1  3081
#define IDCPUVAL2  3082
#define IDCPUVAL3  3083
#define IDCPUVAL4  3084
#define IDCPUVAL5  3085
#define IDCPUVAL6  3086
#define IDCPUVAL7  3087
#define IDCPUVAL8  3088
#define IDCPUVAL9  3089
#define IDCPUVAL10 3090
#define IDCPUVAL11 3091
#define IDCPUVAL12 3092
#define IDCPUVAL13 3093
#define IDCPUVAL14 3094
#define IDCPUVAL15 3095
#define IDCPUVAL16 3096
